from simpleicons.icon import Icon
icon= Icon(
    title="Vagrant",
    slug="vagrant",
    hex="1868F2",
    source="https://www.hashicorp.com/brand",
    svg="""<svg role="img" viewBox="0 0 24 24" xmlns="http://www.w3.org/2000/svg"><title>Vagrant icon</title><path d="M3.556 0L.392 1.846V4.11l7.124 17.3L11.998 24l4.523-2.611 7.083-17.345V1.848l.004-.002L20.44 0l-5.274 3.087v2.111l-3.168 7.384-3.164-7.384V3.109l-.017-.008.017-.01z"/></svg>""",
    guidelines='https://www.hashicorp.com/brand',
    license=None,
)
